Jsonata class
Properties
- controller ↔ InAppWebViewController?
-
getter/setter pair
- data ↔ String
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlessWebView ↔ HeadlessInAppWebView?
-
getter/setter pair
- jql ↔ String
-
getter/setter pair
- results ↔ List
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
webViewCreated
↔ Completer<
void> -
getter/setter pair
Methods
-
dispose(
) → void -
evaluate(
String data) → Future< Map> -
initialize(
) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
query(
[String? jql]) → Future< Map> -
set(
{dynamic data, dynamic jql}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited